==> subfind_provider_subscene-2.0.0.6-py2.py3-none-any.whl: subfind_provider_subscene/__init__.py <==
import logging
import re
import zipfile
from os import listdir
from os.path import join, abspath
from shutil import rmtree
from tempfile import mkdtemp

import requests
from six.moves.urllib.parse import urlencode, urljoin

from subfind_provider import BaseProvider
from subfind_provider.exception import SubtitleFileBroken, HTTPConnectionError
from subfind_provider.movie_parser import parse_release_name
from subfind_provider.parser import Parser
from subfind_provider.release.alice import ReleaseScoringAlice
from subfind_provider.scenario import BaseScenarioFactory, Scenario1
from subfind_provider.utils import get_file_content
from subfind_provider_subscene.language import get_full_lang, get_short_lang

SUBSCENE_SEARCH_URL = "http://subscene.com/subtitles/title?%s"
SUBSCENE_RELEASE_SEARCH_URL = "http://subscene.com/subtitles/release?%s"


class SubsceneFactory(BaseScenarioFactory):
    def get_scenario(self):
        release_scoring = ReleaseScoringAlice()
        provider = SubsceneProvider()

        return Scenario1(release_scoring, provider)


class SubsceneProvider(BaseProvider):
    def __init__(self):
        self.session = requests.Session()

        self.movie_title_year_pattern = re.compile('^(.*)(\s+\((\d+)\))$')
        self.sub_extensions = ['srt', 'sub', 'ass']
        self.logger = logging.getLogger(self.__class__.__name__)

    def search_movie(self, params):
        query = params['title_query']
        base_url = (SUBSCENE_SEARCH_URL % urlencode({'q': query}))

        r = self.session.get(base_url)

        if not r.ok:
            return []

        parser = Parser(r.content)
        nodes = parser.query('//div[@class="title"]/a[contains(@href, "/subtitles/")]')

        movies = []
        processed_urls = set()
        for node in nodes:
            url = node.get('href')
            if url.startswith('/subtitles/release?'):
                continue

            movie_url = urljoin(base_url, url)
            if movie_url in processed_urls:
                continue

            processed_urls.add(movie_url)

            movie_title = node.text.strip()
            m = self.movie_title_year_pattern.search(movie_title)
            movie_year = -1
            if m:
                movie_title = m.group(1).strip()
                if m.group(2):
                    movie_year = int(m.group(3).strip())

            movies.append({
                'title': movie_title,
                'year': movie_year,
                'url': movie_url
            })

        return movies

    def get_movie_subs(self, movie, params, lang):
        movie_url = movie['url']
        # print movie_url
        print(movie_url)
        r = self.session.get(movie_url)
        # print r.content

        m = re.compile('/subtitles/([^/]+)$').search(movie_url)
        movie_slug_name = m.group(1)

        parser = Parser(r.content)
        lang_full_name = get_full_lang(lang)
        nodes = parser.query('//a[contains(@href, "/subtitles/%s/%s/")]' % (movie_slug_name, lang_full_name))

        # pprint(nodes)

        # subtitle_match_str = ' '.join(sorted(params['release_name_tokens']))
        # subtitle_match_tokens = set(params['release_name_tokens'])
        # print 'subtitle_match_str', subtitle_match_str

        subtitles = []
        for node in nodes:
            subtitle_url = node.get('href')
            subtitle_name = node.find('span[2]').text.strip()

            # tmp1 = set(tokenizer(subtitle_name))
            # d = len(subtitle_match_tokens.intersection(tmp1)) * 100 - len(tmp1)

            subtitles.append({
                'url': urljoin(movie_url, subtitle_url),
                'name': subtitle_name,
                # 'd': d
            })

        return subtitles

    def get_sub_file(self, sub_page_url):
        r = self.session.get(sub_page_url)
        if not r.ok:
            # print r.content
            return None

        m = re.search('href=\"(/subtitle/download[^\'"]+)"', r.text)
        if not m:
            # print 'Could not find download url'
            return None

        sub_download_url = urljoin(sub_page_url, m.group(1))

        tmp_folder = mkdtemp(prefix='subfind-')
        try:
            tmp_file = abspath(join(tmp_folder, 'tmp.zip'))

            # run_cmd('rm %s/* -rf' % tmp_folder)

            response = requests.get(sub_download_url, stream=True)
            if not response.ok:
                # Something went wrong
                # print 'could not download sub file'
                return None

            with open(tmp_file, 'wb') as handle:
                for block in response.iter_content(1024):
                    handle.write(block)

            with open(tmp_file, 'rb') as fh:
                z = zipfile.ZipFile(fh)
                num_items = 0
                for item in z.namelist():
                    num_items += 1
                    for sub_extension in self.sub_extensions:
                        if item.endswith('.%s' % sub_extension):
                            z.extract(item, tmp_folder)
                            sub_file = join(tmp_folder, item)
                            return get_file_content(sub_file)

                if num_items == 0:
                    raise SubtitleFileBroken(url=sub_page_url, message='Could not find any file in subtitle file')

                self.logger.warning('There is no subtitle extension found. Files:')
                for item in listdir(tmp_folder):
                    self.logger.warning(item)

            return None
        finally:
            # Remove tmp_folder
            rmtree(tmp_folder)

    def get_releases(self, release_name, langs):
        params = parse_release_name(release_name)
        query = params['release_name']
        base_url = (SUBSCENE_RELEASE_SEARCH_URL % urlencode({'q': query, 'l': '', 'r': 'true'}))

        r = self.session.get(base_url)

        if not r.ok:
            raise HTTPConnectionError(base_url, r.status_code, r.content)

        parser = Parser(r.content)
        release_nodes = parser.query("//td/a[contains(@href, '/subtitles/')]")
        ret = {}
        if not release_nodes:
            return ret

        for release_node in release_nodes:
            release_lang = release_node.find('span[1]').text.strip()
            release_lang = get_short_lang(release_lang)

            if release_lang not in langs:
                continue

            if release_lang not in ret:
                ret[release_lang] = []

            release_name = release_node.find('span[2]').text.strip()

            release_info = parse_release_name(release_name)
            # season_eps must match
            if release_info.get('season_eps') != params.get('season_eps'):
                continue

            release_url = urljoin(base_url, release_node.get('href'))

            release = {
                'name': release_name,
                'lang': release_lang,
                'url': release_url
            }

            ret[release_lang].append(release)

        return ret

==> subfind_provider_subscene-2.0.0.7-py2.py3-none-any.whl: subfind_provider_subscene/__init__.py <==
import logging
import re
import zipfile
from os import listdir
from os.path import join, abspath
from shutil import rmtree
from tempfile import mkdtemp

import requests
from six.moves.urllib.parse import urlencode, urljoin

from subfind import BaseProvider
from subfind.exception import SubtitleFileBroken, HTTPConnectionError
from subfind.model import Subtitle
from subfind.movie_parser import parse_release_name
from subfind.parser import Parser
from subfind.release.alice import ReleaseScoringAlice
from subfind.scenario import BaseScenarioFactory, Scenario1
from subfind.utils import get_file_content
from subfind_provider_subscene.language import get_full_lang, get_short_lang

SUBSCENE_SEARCH_URL = "http://subscene.com/subtitles/title?%s"
SUBSCENE_RELEASE_SEARCH_URL = "http://subscene.com/subtitles/release?%s"


class SubsceneFactory(BaseScenarioFactory):
    def get_scenario(self):
        release_scoring = ReleaseScoringAlice()
        provider = SubsceneProvider()

        return Scenario1(release_scoring, provider)


class SubsceneProvider(BaseProvider):
    def __init__(self):
        self.session = requests.Session()

        self.movie_title_year_pattern = re.compile('^(.*)(\s+\((\d+)\))$')
        self.sub_extensions = ['srt', 'sub', 'ass']
        self.logger = logging.getLogger(self.__class__.__name__)

    def search_movie(self, params):
        query = params['title_query']
        base_url = (SUBSCENE_SEARCH_URL % urlencode({'q': query}))

        r = self.session.get(base_url)

        if not r.ok:
            return []

        parser = Parser(r.content)
        nodes = parser.query('//div[@class="title"]/a[contains(@href, "/subtitles/")]')

        movies = []
        processed_urls = set()
        for node in nodes:
            url = node.get('href')
            if url.startswith('/subtitles/release?'):
                continue

            movie_url = urljoin(base_url, url)
            if movie_url in processed_urls:
                continue

            processed_urls.add(movie_url)

            movie_title = node.text.strip()
            m = self.movie_title_year_pattern.search(movie_title)
            movie_year = -1
            if m:
                movie_title = m.group(1).strip()
                if m.group(2):
                    movie_year = int(m.group(3).strip())

            movies.append({
                'title': movie_title,
                'year': movie_year,
                'url': movie_url
            })

        return movies

    def get_movie_subs(self, movie, params, lang):
        movie_url = movie['url']
        # print movie_url
        print(movie_url)
        r = self.session.get(movie_url)
        # print r.content

        m = re.compile('/subtitles/([^/]+)$').search(movie_url)
        movie_slug_name = m.group(1)

        parser = Parser(r.content)
        lang_full_name = get_full_lang(lang)
        nodes = parser.query('//a[contains(@href, "/subtitles/%s/%s/")]' % (movie_slug_name, lang_full_name))

        # pprint(nodes)

        # subtitle_match_str = ' '.join(sorted(params['release_name_tokens']))
        # subtitle_match_tokens = set(params['release_name_tokens'])
        # print 'subtitle_match_str', subtitle_match_str

        subtitles = []
        for node in nodes:
            subtitle_url = node.get('href')
            subtitle_name = node.find('span[2]').text.strip()

            # tmp1 = set(tokenizer(subtitle_name))
            # d = len(subtitle_match_tokens.intersection(tmp1)) * 100 - len(tmp1)

            subtitles.append({
                'url': urljoin(movie_url, subtitle_url),
                'name': subtitle_name,
                # 'd': d
            })

        return subtitles

    def get_sub_file(self, release):
        sub_page_url = release['url']
        r = self.session.get(sub_page_url)
        if not r.ok:
            # print r.content
            return None

        m = re.search('href=\"(/subtitle/download[^\'"]+)"', r.text)
        if not m:
            # print 'Could not find download url'
            return None

        sub_download_url = urljoin(sub_page_url, m.group(1))

        tmp_folder = mkdtemp(prefix='subfind-')
        try:
            tmp_file = abspath(join(tmp_folder, 'tmp.zip'))

            # run_cmd('rm %s/* -rf' % tmp_folder)

            response = requests.get(sub_download_url, stream=True)
            if not response.ok:
                # Something went wrong
                # print 'could not download sub file'
                return None

            with open(tmp_file, 'wb') as handle:
                for block in response.iter_content(1024):
                    handle.write(block)

            with open(tmp_file, 'rb') as fh:
                z = zipfile.ZipFile(fh)
                num_items = 0
                for item in z.namelist():
                    num_items += 1
                    for sub_extension in self.sub_extensions:
                        if item.endswith('.%s' % sub_extension):
                            z.extract(item, tmp_folder)
                            sub_file = join(tmp_folder, item)
                            content = get_file_content(sub_file)
                            return Subtitle(lang=release['lang'], content=content, extension=sub_extension)

                if num_items == 0:
                    raise SubtitleFileBroken(url=sub_page_url, message='Could not find any file in subtitle file')

                self.logger.warning('There is no subtitle extension found. Files:')
                for item in listdir(tmp_folder):
                    self.logger.warning(item)

            return None
        finally:
            # Remove tmp_folder
            rmtree(tmp_folder)

    def get_releases(self, release_name, langs):
        params = parse_release_name(release_name)
        query = params['release_name']
        base_url = (SUBSCENE_RELEASE_SEARCH_URL % urlencode({'q': query, 'l': '', 'r': 'true'}))

        r = self.session.get(base_url)

        if not r.ok:
            raise HTTPConnectionError(base_url, r.status_code, r.content)

        parser = Parser(r.content)
        release_nodes = parser.query("//td/a[contains(@href, '/subtitles/')]")
        ret = {}
        if not release_nodes:
            return ret

        for release_node in release_nodes:
            release_lang = release_node.find('span[1]').text.strip()
            release_lang = get_short_lang(release_lang)

            if release_lang not in langs:
                continue

            if release_lang not in ret:
                ret[release_lang] = []

            item_release_name = release_node.find('span[2]').text.strip()

            release_info = parse_release_name(item_release_name)
            # season_eps must match
            if release_info.get('season_eps') != params.get('season_eps'):
                continue

            release_url = urljoin(base_url, release_node.get('href'))

            release = {
                'name': item_release_name,
                'lang': release_lang,
                'url': release_url
            }

            ret[release_lang].append(release)

        return ret
